@@ -15,7 +15,8 @@ class InfluxDBClient(object):
     InfluxDB Client
     """
 
-    def __init__(self, host, port, username, password, database):
+    def __init__(self, host='localhost', port=8086, username='root',
+                 password='root', database=None):
         """
         Initialize client
         """
@@ -60,24 +61,11 @@ class InfluxDBClient(object):
     # by doing a POST to /db/foo_production/series?u=some_user&p=some_password
     # with a JSON body of points.
 
-    def write_points(self, data):
+    def write_points(self, *args, **kwargs):
         """
         Write to multiple time series names
         """
-        response = session.post(
-            "{0}/db/{1}/series?u={2}&p={3}".format(
-                self._baseurl,
-                self._database,
-                self._username,
-                self._password),
-            data=json.dumps(data),
-            headers=self._headers)
-
-        if response.status_code == 200:
-            return True
-        else:
-            raise Exception(
-                "{0}: {1}".format(response.status_code, response.content))
+        return self.write_points_with_precision(*args, **kwargs)
 
     def write_points_with_precision(self, data, time_precision='s'):
         """
@@ -243,6 +231,46 @@ class InfluxDBClient(object):
             raise Exception(
                 "{0}: {1}".format(response.status_code, response.content))
 
+    # ### get list of databases
+    # curl -X GET http://localhost:8086/db
+
+    def get_database_list(self):
+        """
+        Get the list of databases
+        """
+        response = session.get("{0}/db?u={1}&p={2}".format(
+            self._baseurl,
+            self._username,
+            self._password))
+
+        if response.status_code == 200:
+            return json.loads(response.content)
+        else:
+            raise Exception(
+                "{0}: {1}".format(response.status_code, response.content))
+
+    def delete_series(self, series):
+        """
+        Drop a series
+
+        Parameters
+        ----------
+        series: string
+            series name
+        """
+        response = session.delete("{0}/db/{1}/series/{2}?u={3}&p={4}".format(
+            self._baseurl,
+            self._database,
+            series,
+            self._username,
+            self._password))
+
+        if response.status_code == 204:
+            return True
+        else:
+            raise Exception(
+                "{0}: {1}".format(response.status_code, response.content))
+
     # Security
     # get list of cluster admins
     # curl http://localhost:8086/cluster_admins?u=root&p=root
